==> hledger-1.42.1.tar.gz: hledger-1.42.1/doc/FINANCE.md <==
# Project finances

<div class=pagetoc>

<!-- toc -->
</div>

This is the home for the hledger project's finances. (Shortcut: [hledger.org/finance](https://hledger.org/finance))

## Money and the hledger project

Classic gift-economy FOSS communities are a beautiful and precious thing.
Adding money, or adding money in the wrong way, can change or damage them.
Yet, from the beginning I intended this project to be accountable, solvent and self-funding - ideally, not a money pit.
And we need to be exploring new ways to integrate FOSS and money.
And in many ways this project is ideal for that.
So money is part of the hledger project, we welcome it, and we experiment with it, cautiously, to see what works.
The CFO is SM; help is welcome.
<!-- I know we would enjoy having more bugs resolved, more and better features, and a faster rate of improvement. -->

You can review our [Financial reports](https://github.com/simonmichael/hledger_finance?tab=readme-ov-file#reports) here.

You can [Sponsor hledger](sponsor.md) to support and grow this project.

You can earn [Regression bounties](REGRESSIONS.md) by reporting or fixing regression bugs.

## Issue bounties

More generally, bounties are sometimes offered to encourage completion of a bug fix, or a new feature.
To earn bounties, try to resolve issues with the bounty label.\
Here are the [issue bounties](https://github.com/simonmichael/hledger/issues/?q=is%3Aissue%20state%3Aopen%20label%3Abounty).

Anyone can offer bounties. There are two kinds:

**Honour bounties**\
You or your organisation can offer a bounty simply by saying so on the issue.
Progress and payment are discussed there and handled on the honour system.
The Bounty Manager is SM.

**Open Collective bounties**\
Or the hledger project may offer bounties for specific issues, from our Open Collective fund.
Feel free to suggest issues which might benefit from this.
When you complete an OC bounty, submit an expense reimbursement request to [hledger's open collective](https://opencollective.com/hledger),
similar to claiming a [regression bounty](REGRESSIONS.md).

Our bounty amounts have so far been small, but they help us experiment with process and establish a principle of sustainability.
When you earn a bounty we encourage you to claim it. But if you prefer, you can offer it as a new bounty on an issue of your choice.

## Funded projects

We welcome proposals for new funded projects (since 2025).
Anyone can propose a project and an amount they'll do it for,
and if approved, do the work, and as deliverables are met, we'll pay you.
The hledger project's cashflow is currently rather limited,
so we invite other organisations or individuals to help fund projects (or call for proposals).
Each proposal begins as an issue, which gets the `funded-project` label when approved.
Here are the [funded projects](https://github.com/simonmichael/hledger/issues/?q=is%3Aissue%20state%3Aopen%20label%3Afunded-project).

==> hledger-1.43.1.tar.gz: hledger-1.43.1/doc/FINANCE.md <==
# Project finances

<div class=pagetoc>

<!-- toc -->
</div>

This is the home for the hledger project's finances. (Shortcut: [hledger.org/finance](https://hledger.org/finance))

## Reports

We log the hledger project's financial transactions and generate reports in the 
[hledger_finance repo](https://github.com/simonmichael/hledger_finance).
There you can review our [financial reports](https://github.com/simonmichael/hledger_finance?tab=readme-ov-file#reports).

## Money and the hledger project

Classic gift-economy FOSS communities are a beautiful and precious thing.
Adding money, or adding money in the wrong way, can change or damage them.
Yet, from the beginning I intended this project to be accountable, solvent and self-funding - ideally, not a money pit.
And we need to be exploring new ways to integrate FOSS and money.
And in many ways this project is ideal for that.
So money is part of the hledger project, we welcome it, and we experiment with it, cautiously, to see what works.
The CFO is SM; help is welcome.
<!-- I know we would enjoy having more bugs resolved, more and better features, and a faster rate of improvement. -->

You can [Sponsor hledger](sponsor.md) to support and grow this project.

You can earn [Regression bounties](REGRESSIONS.md) by reporting or fixing regression bugs.

## Issue bounties

More generally, bounties are sometimes offered to encourage completion of a bug fix, or a new feature.
To earn bounties, try to resolve issues with the bounty label.\
Here are the [issue bounties](https://github.com/simonmichael/hledger/issues/?q=is%3Aissue%20state%3Aopen%20label%3Abounty).

Anyone can offer bounties. There are two kinds:

**Honour bounties**\
You or your organisation can offer a bounty simply by saying so on the issue.
Progress and payment are discussed there and handled on the honour system.
The Bounty Manager is SM.

**Open Collective bounties**\
Or the hledger project may offer bounties for specific issues, from our Open Collective fund.
Feel free to suggest issues which might benefit from this.
When you complete an OC bounty, submit an expense reimbursement request to [hledger's open collective](https://opencollective.com/hledger),
similar to claiming a [regression bounty](REGRESSIONS.md).

Our bounty amounts have been relatively small so far, but they help us experiment with process and establish a principle of sustainability.
When you are awarded a bounty, we encourage you to claim it.
But if you prefer, you can donate it back to the project, or declare it as a new bounty on an issue of your choice.

## Funded projects

We welcome proposals for new funded projects (since 2025).
Anyone can propose a project and an amount they'll do it for,
and if approved, do the work, and as deliverables are met, we'll pay you.
The hledger project's cashflow is currently rather limited,
so we invite other organisations or individuals to help fund projects (or call for proposals).
Each proposal begins as an issue, which gets the `funded-project` label when approved.
Here are the [funded projects](https://github.com/simonmichael/hledger/issues/?q=is%3Aissue%20state%3Aopen%20label%3Afunded-project).
